From feecb79eee7cad92e17bd526b3bf6e5d28dd904c Mon Sep 17 00:00:00 2001
From: Thomas Fischer <thomas.fischer@ufz.de>
Date: Wed, 16 Mar 2016 19:37:33 +0100
Subject: [PATCH] [GL] SimplePolygonTree: rename _childs -> _children.

---
 FileIO/GmshIO/GMSHPolygonTree.cpp | 20 ++++++++++----------
 FileIO/GmshIO/GMSHPolygonTree.h   |  2 +-
 GeoLib/SimplePolygonTree.cpp      |  8 ++++----
 GeoLib/SimplePolygonTree.h        |  8 ++++----
 4 files changed, 19 insertions(+), 19 deletions(-)

diff --git a/FileIO/GmshIO/GMSHPolygonTree.h b/FileIO/GmshIO/GMSHPolygonTree.h
index dfcbb6811fc..bc33d49bafe 100644
--- a/FileIO/GmshIO/GMSHPolygonTree.h
+++ b/FileIO/GmshIO/GMSHPolygonTree.h
@@ -58,7 +58,7 @@ public:
 	 * polyline, i.e. the two intersecting line segments are splitt into four line segment.
 	 *
 	 * Line segments of the polyline that are completely within the polygon are inserted into
-	 * the internal vector _gmsh_lines_for_constraints. The childs of this GMSHPolygonTree node
+	 * the internal vector _gmsh_lines_for_constraints. The children of this GMSHPolygonTree node
 	 * are checked recursively.
 	 * @param ply the polyline that should be inserted
 	 */
diff --git a/GeoLib/SimplePolygonTree.cpp b/GeoLib/SimplePolygonTree.cpp
index b42d31955d7..e288664a2a8 100644
--- a/GeoLib/SimplePolygonTree.cpp
+++ b/GeoLib/SimplePolygonTree.cpp
@@ -22,7 +22,7 @@ SimplePolygonTree::SimplePolygonTree(Polygon * polygon, SimplePolygonTree * pare
 
 SimplePolygonTree::~SimplePolygonTree()
 {
-	for (auto * child : _childs) {
+	for (auto * child : _children) {
 		delete child;
 	}
 }
@@ -36,15 +36,15 @@ void SimplePolygonTree::insertSimplePolygonTree (SimplePolygonTree* polygon_hier
 {
 	const Polygon* polygon (polygon_hierarchy->getPolygon());
 	bool nfound (true);
-	for (std::list<SimplePolygonTree*>::const_iterator it (_childs.begin());
-	     it != _childs.end() && nfound; ++it) {
+	for (std::list<SimplePolygonTree*>::const_iterator it (_children.begin());
+	     it != _children.end() && nfound; ++it) {
 		if (((*it)->getPolygon())->isPolylineInPolygon (*(polygon))) {
 			(*it)->insertSimplePolygonTree (polygon_hierarchy);
 			nfound = false;
 		}
 	}
 	if (nfound) {
-		_childs.push_back (polygon_hierarchy);
+		_children.push_back (polygon_hierarchy);
 		polygon_hierarchy->setParent(this);
 	}
 }
diff --git a/FileIO/GmshIO/GMSHPolygonTree.cpp b/FileIO/GmshIO/GMSHPolygonTree.cpp
index 634534ad517..e8899e9a46e 100644
--- a/FileIO/GmshIO/GMSHPolygonTree.cpp
+++ b/FileIO/GmshIO/GMSHPolygonTree.cpp
@@ -50,8 +50,8 @@ bool GMSHPolygonTree::insertStation(GeoLib::Point const* station)
 {
 	if (_node_polygon->isPntInPolygon(*station)) {
 		// try to insert station into the child nodes
-		for (std::list<SimplePolygonTree*>::const_iterator it (_childs.begin());
-			 it != _childs.end(); ++it) {
+		for (std::list<SimplePolygonTree*>::const_iterator it (_children.begin());
+			 it != _children.end(); ++it) {
 			if (((*it)->getPolygon())->isPntInPolygon (*station)) {
 				bool rval(dynamic_cast<GMSHPolygonTree*>((*it))->insertStation (station));
 				// stop recursion if sub SimplePolygonTree is a leaf
@@ -71,9 +71,9 @@ bool GMSHPolygonTree::insertStation(GeoLib::Point const* station)
 void GMSHPolygonTree::insertPolyline (GeoLib::PolylineWithSegmentMarker * ply)
 {
 	if (_node_polygon->isPartOfPolylineInPolygon(*ply)) {
-		// check childs
-		for (std::list<SimplePolygonTree*>::const_iterator it (_childs.begin());
-			it != _childs.end(); ++it) {
+		// check children
+		for (std::list<SimplePolygonTree*>::const_iterator it (_children.begin());
+			it != _children.end(); ++it) {
 			dynamic_cast<GMSHPolygonTree*>((*it))->insertPolyline (ply);
 		}
 		_plys.push_back(ply);
@@ -190,8 +190,8 @@ void GMSHPolygonTree::createGMSHPoints(std::vector<FileIO::GMSH::GMSHPoint*> & g
 		}
 	}
 
-	// walk through childs
-	for (std::list<SimplePolygonTree*>::const_iterator it (_childs.begin()); it != _childs.end(); ++it) {
+	// walk through children
+	for (std::list<SimplePolygonTree*>::const_iterator it (_children.begin()); it != _children.end(); ++it) {
 		dynamic_cast<GMSHPolygonTree*>((*it))->createGMSHPoints(gmsh_pnts);
 	}
 }
@@ -235,7 +235,7 @@ void GMSHPolygonTree::writeLineConstraints(std::size_t &line_offset, std::size_t
 
 void GMSHPolygonTree::writeSubPolygonsAsLineConstraints(std::size_t &line_offset, std::size_t sfc_number, std::ostream& out) const
 {
-	for (std::list<SimplePolygonTree*>::const_iterator it (_childs.begin()); it != _childs.end(); ++it) {
+	for (std::list<SimplePolygonTree*>::const_iterator it (_children.begin()); it != _children.end(); ++it) {
 		dynamic_cast<GMSHPolygonTree*>((*it))->writeSubPolygonsAsLineConstraints(line_offset, sfc_number, out);
 	}
 
@@ -309,7 +309,7 @@ void GMSHPolygonTree::getPointsFromSubPolygons(std::vector<GeoLib::Point const*>
 		pnts.push_back(_node_polygon->getPoint(k));
 	}
 
-	for (std::list<SimplePolygonTree*>::const_iterator it (_childs.begin()); it != _childs.end(); ++it) {
+	for (std::list<SimplePolygonTree*>::const_iterator it (_children.begin()); it != _children.end(); ++it) {
 		dynamic_cast<GMSHPolygonTree*>((*it))->getPointsFromSubPolygons(pnts);
 	}
 }
@@ -321,7 +321,7 @@ void GMSHPolygonTree::getStationsInsideSubPolygons(std::vector<GeoLib::Point con
 		stations.push_back(_stations[k]);
 	}
 
-	for (std::list<SimplePolygonTree*>::const_iterator it (_childs.begin()); it != _childs.end(); ++it) {
+	for (std::list<SimplePolygonTree*>::const_iterator it (_children.begin()); it != _children.end(); ++it) {
 		dynamic_cast<GMSHPolygonTree*>((*it))->getStationsInsideSubPolygons(stations);
 	}
 }
diff --git a/GeoLib/SimplePolygonTree.h b/GeoLib/SimplePolygonTree.h
index 8d60516464c..d5b547efe37 100644
--- a/GeoLib/SimplePolygonTree.h
+++ b/GeoLib/SimplePolygonTree.h
@@ -44,7 +44,7 @@ public:
 	 */
 	bool isPolygonInside (const SimplePolygonTree* polygon_tree) const;
 	/** Either insert the given SimplePolygonTree in one of the existing
 	 * childs or as a new child.
 	 */
 	void insertSimplePolygonTree (SimplePolygonTree* polygon_tree);
 
@@ -54,8 +54,8 @@ public:
 	 */
 	const Polygon* getPolygon () const;
 
-	/** returns the number of childs */
-	std::size_t getNChildren() const { return _childs.size(); }
+	/** returns the number of children */
+	std::size_t getNChildren() const { return _children.size(); }
 
 protected:
 	/**
@@ -71,7 +71,7 @@ protected:
 	 * list of polygons (represented by SimplePolygonTree nodes) contained
 	 * in the _node_polygon
 	 */
-	std::list<SimplePolygonTree*> _childs;
+	std::list<SimplePolygonTree*> _children;
 
 private:
 	void setParent(SimplePolygonTree* parent)
@@ -44,7 +44,7 @@ public:
 	bool isPolygonInside (const SimplePolygonTree* polygon_tree) const;
 	/** Either insert the given SimplePolygonTree in one of the existing
-	 * childs or as a new child.
+	 * children or as a new child.
 	 */
 	void insertSimplePolygonTree (SimplePolygonTree* polygon_tree);
-- 
GitLab